"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebSocketConnectionManager = exports.ConnectionNotFoundError = void 0;
const errors_1 = require("./errors");
class ConnectionNotFoundError extends errors_1.ExtendableError {
}
exports.ConnectionNotFoundError = ConnectionNotFoundError;
class WebSocketConnectionManager {
    connections;
    constructor() {
        this.connections = new Map();
    }
    hydrateConnection = async (connectionId) => {
        // if connection is not found, throw so we can terminate connection
        const connection = this.connections.get(connectionId);
        if (connection == null) {
            throw new ConnectionNotFoundError(`Connection ${connectionId} not found`);
        }
        return connection;
    };
    setConnectionData = async (data, connection) => {
        this.connections.set(connection.id, {
            socket: connection.socket,
            id: connection.id,
            data,
        });
    };
    registerConnection = async ({ connectionId, endpoint, socket, }) => {
        const connection = {
            socket,
            id: connectionId,
            data: { endpoint, context: {}, isInitialized: false },
        };
        this.connections.set(connectionId, connection);
        return connection;
    };
    sendToConnection = (connection, payload) => {
        return new Promise((resolve, reject) => {
            try {
                connection.socket.send(payload, (err) => err ? reject(err) : resolve());
            }
            catch (e) {
                reject(e);
            }
        });
    };
    unregisterConnection = async (connection) => {
        this.connections.delete(connection.id);
    };
    closeConnection = async (connection) => {
        setTimeout(() => {
            // wait so we can send error message first
            connection.socket.close(1011);
        }, 10);
    };
}
exports.WebSocketConnectionManager = WebSocketConnectionManager;
//# sourceMappingURL=WebSocketConnectionManager.js.map